import Taro from "@tarojs/taro";
import { View, Image } from "@tarojs/components";
import WidgetCard from "@/components/widgets/widget-card/index";
import style from "./index.module.less";
import type { IEntityDocument, TEntityComponent } from "@/types/index";
interface Props {
  index: number;
  editMode: boolean;
  component: TEntityComponent;
  components: TEntityComponent[];
  onSwitchChanged: (c: TEntityComponent, checked: boolean) => void;
  onDelete: (c: IEntityDocument) => void;
  onMove: (c: TEntityComponent, direction: number) => void;
  onClick: (c: TEntityComponent, url: string) => void;
}

export default ({
  index,
  editMode,
  component,
  components,
  onSwitchChanged,
  onDelete,
  onMove,
  onClick,
}: Props) => {
  const data =
    component.data ||
    ({ value: {} } as {
      value: {
        shortLink: string;
        poster: string;
        name: string;
      };
    });
  // 非编辑模式背景显示为白色
  // const editModeStyle = editMode ? style.editMode : style.showMode;
  
  const handleClick = (e) => {
    if (editMode) {
      e.stopPropagation()
      onClick(component, `/pages/editor-pages/editor-store-product/index`);
    }
  };

  return (
    <>
      <WidgetCard
        className={style.card}
        disableChangeStyle
        index={index}
        enabled={component.enabled}
        onSwitchChanged={(checked) => onSwitchChanged(component, checked)}
        components={components}
        editMode={editMode}
        onDelete={() => onDelete(component)}
        onMove={(direction) => onMove(component, direction)}
      >
        <View className={`relative px-4`} onClick={handleClick}>
          {editMode && <View className="absolute w-full h-full z-10 left-0 top-0"></View>}
          {/*@ts-ignore*/}
          <store-product-item product-id={data.value.productId} appid={data.value.appid} />
        </View>
      </WidgetCard>
    </>
  );
};
