import { View, Text, Image } from "@tarojs/components";
import Taro, { useDidShow } from "@tarojs/taro";
import NavBar from "@/components/nav-bar/index";
import { useAppStore } from "@/store/appStore";
import style from "./index.module.less";
import { getWeeklyStats, getChatHistories } from "@/service/stats";
import { useState } from "react";
import { TWeeklyChatStatistics, TEntityChatSession } from "@/types/index";
import IconPeople from "@/images/icon-people.png";
import { formatDateFull } from "@/utils/index";
import { useUserStore } from "@/store/userStore";
import { APP_NAME_TEXT } from '@/config'
import { reportPageVisit } from "@/utils/report";
import TabPageWrapper from "@/components/tab-page-wrapper/index";
export default () => {
  const headerHeight = useAppStore((state) => state.headerHeight);
  const [stats, setStats] = useState<TWeeklyChatStatistics | null>(null);
  const [chatHistories, setChatHistories] = useState<TEntityChatSession[] | []>(
    []
  );
  const user = useUserStore((state) => state.user);
  const isVip = user?.vip !== "vip_free";
  const fetchStatsData = async () => {
    const res = await getWeeklyStats();
    if (res?.data) {
      setStats(res.data);
    }
  };
  const fetchHistories = async () => {
    const res = await getChatHistories({ page: 1, pageSize: 50 });
    if (res?.data) {
      setChatHistories(res.data);
    }
  };
  const handleNav = (item: TEntityChatSession) => {
    Taro.navigateTo({
      url: `/pages/chat-history/index?sessionId=${item.sessionId}&characterName=${item.characterName}&createAt=${item.createdAt}&num=${item.num}`,
    });
  };
  const gohome = ()=> {
    Taro.switchTab({
      url: '/pages/index/index'
    })
  }
  const go2Vip = ()=> {
    Taro.switchTab({
      url: '/pages/member/index'
    })
  }
  useDidShow(() => {
    fetchStatsData();
    if(isVip){
      fetchHistories();  
    }
  });

  reportPageVisit();

  const renderList = ()=> {
    if(chatHistories?.length){
      return <>
      {chatHistories.map((item: TEntityChatSession) => {
        return (
          <View
            className={`${style.chatItem}`}
            onClick={() => handleNav(item)}
          >
            <Image
              src={IconPeople}
              className="w-28 h-28 rounded-6"
            ></Image>
            <View className={style.turnRow}>
              <View className={style.turnNum}>{item.num}</View>
              <View className={style.turnText}>轮</View>
            </View>
            <View className={style.datetime}>
              {formatDateFull(new Date(item.createdAt))}
            </View>
            <View className={style.userName}>
              {item.characterName}
            </View>
          </View>
        );
      })}
      </>
    }
      
    return <View className="flex flex-col pt-56 items-center">
      <View className='data-empty'></View>
      <View className='text-12 text-gray-45 text-center leading-24 mt-12'>暂时没有互动记录，请先创建{APP_NAME_TEXT}</View>
      <View className='full-rounded-button mt-20' style={{paddingLeft: '90px', paddingRight: '90px'}} onClick={gohome}>创建{APP_NAME_TEXT}</View>
    </View>
  }
  return (
    <TabPageWrapper>
      <NavBar>
        <View className="flex items-center">
          <Text>聊天分析</Text>
        </View>
      </NavBar>
      
      <View className="w-full">
        {!isVip && <View className="absolute bottom-0 left-0 right-0 z-10 popup-vip-tips" onClick={go2Vip}>
          <Image className='w-full' src='https://cdn.wehome.cn/cmn/png/214/META-H8UKYHWU-E9EPKMQUBSVOJ4T4NHO63-MKACO82M-A9.png' mode="widthFix"></Image>
        </View>
        }
        <View
          className={`flex px-20 py-40 bg-white rounded-20 gap-20 mb-40 w-full ${style.dashboardScoreBar}`}
        >
          <View className={`flex flex-col flex-1 gap-4}`}>
            <Text className={style.dashboardScore}>
              {stats?.weeklyNewUsers ?? 0}
            </Text>
            <View className={style.dashboardSubText}>本周聊天人数</View>
          </View>
          <View className="flex flex-col flex-1 gap-4">
            <Text className={style.dashboardScore}>
              {stats?.weeklyTotalChats ?? 0}
            </Text>
            <View className={style.dashboardSubText}>本周聊天轮次</View>
          </View>
        </View>

        <View className="mb-16 text-black text-18 leading-26 font-medium">
          最新互动
        </View>

        <View className={style.chatList}>
          {renderList()}
        </View>
      </View>
    </TabPageWrapper>
  );
};
