import { useState } from "react";
import { View } from "@tarojs/components";

import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import WemetaInput from "@/components/wemeta-input/index";
import editorStyle from "../editor.module.less";
import Taro, { useUnload } from "@tarojs/taro";
import { useCharacterStore } from "@/store/characterStore";
import { useComponentStore } from "@/store/componentStore";

export default function Index() {
  const $instance = Taro.getCurrentInstance();
  const id = $instance.router?.params.id;
  const deltaNum = id ? 1 : 2;
  let currentComponent = useComponentStore((state) => state.currentComponent);
  const character = useCharacterStore((state) => state.character);
  const { saveComponent } = useComponentStore();
  const loading = useComponentStore((state) => state.loading);
  const { job, department, company } = currentComponent?.data ?? {};
  const [value, setValue] = useState({
    job: job ?? "",
    department: department ?? "",
    company: company ?? "",
  });

  const onChange = (key: string, v: string) => {
    value[key] = v;
    setValue({
      ...value,
    });
  };

  const handleSave = async () => {
    if (
      !value.job?.length &&
      !value.department?.length &&
      !value.company?.length
    ) {
      return;
    }
    if (loading) {
      return;
    }
    const c = {
      data: {
        job: value.job,
        department: value.department,
        company: value.company,
      },
      enabled: currentComponent?.enabled ?? true,
      id: currentComponent?.id,
      name: currentComponent?.name ?? "商务名片",
      characterProfileId:
        currentComponent?.characterProfileId ?? character?.profileId,
      type: "businessCard",
    };

    await saveComponent(c);
  };

  const handleNavBack = async () => {
    await handleSave();
  };

  return (
    <PageCustom bgColor="global-light-green-bg">
      <NavBarNormal backText="保存" navDelta={deltaNum} onNavBack={handleNavBack}>
        商务名片
      </NavBarNormal>
      <View className="flex flex-col items-center w-full">
        <View className={editorStyle.container}>
          <View className={editorStyle.formContainer}>
            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>职位</View>
              <WemetaInput
                  value={value.job}
                  onInput={(value: string) => onChange("job", value)}
                  placeholder="请输入"
                />
            </View>
            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>部门</View>
              <WemetaInput
                  value={value.department}
                  onInput={(value: string) => onChange("department", value)}
                  placeholder="请输入"
                />
            </View>
            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>公司</View>
              <WemetaInput
                  value={value.company}
                  onInput={(value: string) => onChange("company", value)}
                  placeholder="请输入"
                />
            </View>
          </View>
        </View>
      </View>
    </PageCustom>
  );
}
