import { useState } from "react";
import { View, Textarea } from "@tarojs/components";

import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import editorStyle from "../editor.module.less";
import { useCharacterStore } from '@/store/characterStore'
import { useComponentStore } from "@/store/componentStore";
import Taro, { useUnload } from "@tarojs/taro";
import WemetaTextarea from "@/components/wemeta-textarea/index";

export default function Index() {
  const $instance = Taro.getCurrentInstance()
  const id = $instance.router?.params.id
  const deltaNum = id ? 1:2;
  let currentComponent = useComponentStore((state)=>  state.currentComponent);
  const character = useCharacterStore((state)=> state.character);
  const { saveComponent } = useComponentStore();
  const loading = useComponentStore((state)=> state.loading);

  const [value, setValue] = useState({
    business: currentComponent?.data?.business ?? '',
    company: currentComponent?.data?.company ?? '',
  });

  const onChange = (key: string, v: string) => {
    value[key] = v;
    setValue({
      ...value,
    });
  };


  const handleSave = async () => {
    
    if(!value.business?.length && !value.company?.length){
      return
    }
    if(loading){
      return;
    }
    const c = {
      data: {
        business: value.business,
        company: value.company,
      },
      enabled: currentComponent?.enabled ?? true,
      id: currentComponent?.id,
      name: currentComponent?.name ?? "公司信息",
      characterProfileId: currentComponent?.characterProfileId ?? character?.profileId,
      type: "company",
    };
    
    await saveComponent(c)
  };

  const handleNavBack =  async () => {
    await handleSave();
  };
  
  return (
    <PageCustom bgColor="global-light-green-bg">
      <NavBarNormal backText="保存" navDelta={deltaNum} onNavBack={handleNavBack}>公司信息</NavBarNormal>
      <View className="flex flex-col items-center w-full">
        <View className={editorStyle.container}>
          <View className={editorStyle.formContainer}>
            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>公司简介</View>
              <WemetaTextarea
                  value={value.company}
                  onInput={(value: string) => onChange("company", value)}
                  placeholder="请输入..."
                />
            </View>

            <View className={editorStyle.formItem}>
              <View className={editorStyle.formItemLabel}>业务介绍</View>
              <WemetaTextarea
                    value={value.business}
                    onInput={(value: string) => onChange("business", value)}
                    cursorSpacing={200}
                    placeholder="请输入..."
                  />
            </View>
          </View>
        </View>
      </View>
    </PageCustom>
  );
}
