import { useRef, useEffect, useState, useMemo } from 'react'
import { View, Text, Button, Image } from "@tarojs/components";
import ChatAI, {IChatAIComponent} from '@/components/chat-ai/index'
import style from "./index.module.less";
import type { ICharacter } from "@/types";
import Taro from "@tarojs/taro";
import IconEditFill from '@/images/icon_20_edit.png'
import IconShare from '@/images/icon_20_share.png'
import { handleShare } from '@/utils/share';
import SharePopup from '@/components/custom-share/share-popup/index';
import { useCharacterStore } from "@/store/characterStore";

interface Props {
  character: ICharacter
  playGreeting: boolean
  currentIndex: number
  index: number
}
export default function Index({ character, currentIndex, index }: Props) {
  const [sharePopupVisible, setSharePopupVisible] = useState(false)
  const chatAIRef = useRef<IChatAIComponent>(null)
  const {
    setCurrentCharacter,
  } = useCharacterStore();
  const handleEdit = ()=> {
    if(character){
      setCurrentCharacter(character) 
      Taro.navigateTo({url: `/pages/page/index?profileId=${character.profileId}`})
    }
  }

  const handleShareClick = ()=> {
    handleShare();
    Taro.hideTabBar();
    setSharePopupVisible(true)
  }
  const handleSharePopupClosed = ()=> {
    Taro.showTabBar();
    setSharePopupVisible(false)
  }

  useEffect(()=> {
    if(currentIndex !== index){
      chatAIRef.current?.stop()
    }
  }, [currentIndex, index])

  return (
    <View className={`flex flex-col items-center relative ${style.swiperCard}`}>
      <View className={`absolute left-0 top-0 z-10 ${style.cardContainer}`}>
        <ChatAI buttonSize='small' ref={chatAIRef} getSession={(currentIndex+1) === index} shareButton={false} playGreeting={false} enableGoPreview character={character}></ChatAI>
        <View className={`border-t border-t-gray-4 black-light ${style.cardButtons}`}>
          <View className={style.cardButtonRow}>
            <View
              className={`flex gap-4 items-center rounded-bl-20 ${style.cardButton}`}
              onClick={handleEdit}
            >
              <Image src={IconEditFill} className="w-20 h-20"></Image>
              <Text>编辑</Text>
            </View>
            <View
              className={`flex gap-4 items-center rounded-br-20 ${style.cardButton} relative`}
              onClick={handleShareClick}
            >
              <Image src={IconShare} className="w-20 h-20"></Image>
              <Text>分享</Text>
              {/* <Button openType="share" className="share-button"></Button> */}
            </View>
          </View>
        </View>
        <SharePopup character={character} visible={sharePopupVisible} onClose={handleSharePopupClosed}></SharePopup>
      </View>
    </View>
  );
}
