import { View, Image } from '@tarojs/components'
import style from  './index.module.less'
import Taro from '@tarojs/taro';
import type {ITouchEvent} from '@tarojs/components'
import { useAppStore } from '@/store/appStore'
import { APP_NAME_TEXT, IS_MINI_GREEN_LEAF } from '@/config'

interface Props {
  length: number
  onClick: () => void
}
export default function  Index({length, onClick}:Props){

  const appConfig = useAppStore((state) => state.appConfig);

  const handleClick = () => {
    onClick()
  }

  const go2Help = (e:ITouchEvent)=> {
    const guidanceLink = appConfig?.guidanceLink
    e.stopPropagation();
    // 如果服务端有配置
    if(guidanceLink){
      // 角色详情页跳转
      if(guidanceLink.startsWith('character://')){
        const profileId = guidanceLink.slice(12)
        Taro.navigateTo({url: '/pages/profile/index?profileId='+profileId})
        return
      }
      // 普通https连接
      if(guidanceLink.startsWith('https://')){
        Taro.navigateTo({
          url: `/pages/webview/index?url=${guidanceLink}`
        })
        return
      }
    }
    // 如果服务端没配置则默认跳转此页
    Taro.navigateTo({
      url: '/pages/webview/index?url=https://mp.weixin.qq.com/s/9Goo814D4GObS9H9ObCFyA'
    })
  }

  return (
    <View className={`flex flex-col gap-16 justify-center items-center relative ${style.swiperCard}`} onClick={handleClick}>
      <View className={style.createButton}>
        <Image src='https://cdn.wehome.cn/cmn/png/100/META-H8UKVHWU-KIGP3BIL7M5AYC6XHNUA2-VDZCWI2M-O91.png' className={style.iconAdd}></Image>
      </View>
      <View className='text-center'>
        <View className={style.tips}>
          {length === 0 ? '创建你的第一张AI主页': '创建主页'}
        </View>
      </View>

      {IS_MINI_GREEN_LEAF && <View className={style.bottomButtonContainer}>
          <View className={style.helpButton} onClick={go2Help}>
            <View>🤔</View>
            <View>{APP_NAME_TEXT}可以帮你做什么?</View>
          </View>
        </View>}
    </View>
  )
}
