import { View } from "@tarojs/components";
import Taro from "@tarojs/taro";
import { useEffect, useState } from "react";
import style from "./index.module.less";

import { TFileItem } from '@/types/file-types'
import { uploadFileManager } from '@/utils/http'
import { EUploadFileScene } from '@/types'

interface Props {
  file: TFileItem;
  onUploaded: (res: any, file: TFileItem) => void;
  onStart: (
    task: Taro.UploadTask.UploadTaskPromise | null,
    fileItem: TFileItem
  ) => void;
}

export default ({ file, onUploaded, onStart }: Props) => {
  const [fileProgress, setFileProgress] = useState(0);
  const uploadAction = (fileItem: TFileItem) => {
    
    
    let uploadTask: Taro.UploadTask.UploadTaskPromise | null;
    if (process.env.TARO_ENV == "h5") {
      uploadTask = uploadFileManager(
        fileItem.file.name,
        EUploadFileScene.DOC,
        (res) => {
          console.log("h5 文件已经上传");
          onUploaded(res, fileItem);
          return {
            code: 0,
            data: "",
            msg: "",
          };
        },
        {
          file: fileItem.file as File,
        }
      );
    } else {
      uploadTask = uploadFileManager(fileItem.file.path, EUploadFileScene.DOC, (res:any) => {
        console.log(res)
        onUploaded(res, fileItem)
      })
    }

    uploadTask?.onProgressUpdate((res) => {
      setFileProgress(res.progress);
      // console.log('上传进度', res.progress)
      // console.log('已经上传的数据长度', res.totalBytesSent)
      // console.log('预期需要上传的数据总长度', res.totalBytesExpectedToSend)
    });



    onStart(uploadTask, fileItem);
    // uploadTask.abort() // 取消上传任务
  };

  useEffect(() => {
    if (file.status === 0) {
      uploadAction(file);
    }
  }, [file]);

  return (
    <View className={style.progressBar}>
      <View
        className={style.progress}
        style={{ width: `${fileProgress}%` }}
      ></View>
    </View>
  );
};
