/**
 * 对话
 */

import { useRef, useState, type ChangeEvent } from "react";
import { Image, View } from "@tarojs/components";

import PageCustom from "@/components/page-custom/index";
import NavBarNormal from "@/components/nav-bar-normal/index";
import style from "./index.module.less";
import Taro, { useDidShow, useReady } from "@tarojs/taro";
import DocTips from "./components/doc-tips/index";
import UploadingDocList from "./components/uploading-list/index";
import RenderIcon from "./components/doc-icon/index";
import { useDocumentStore } from "@/store/documentStore";
import { useCharacterStore } from "@/store/characterStore";
import { useAppStore } from "@/store/appStore";
import { TFileItem } from "@/types/file-types";
import { IEntityDocument } from "@/types/index";
import { getSuffix } from "@/utils";
const fileTypes = ["doc", "docx", "xls", "xlsx", "pdf", "txt", "ppt"];


export default function Index() {
  const documents = useDocumentStore((state) => state.documents);
  const uploadingList = useDocumentStore((state) => state.uploadingList);
  const vip = useAppStore((state) => state.vip);
  const {setVipPopupVisible} = useAppStore()
  const { fetchDocumentList, deleteDocument, setUploadingList } =
    useDocumentStore();
  const character = useCharacterStore((state) => state.character);
  const [uploadList, setUploadList] = useState<TFileItem[]>([]);
  const inputRef = useRef<HTMLInputElement>(null);
  const handleH5FileChange = (e: ChangeEvent<HTMLInputElement>) => {
    const selectedFiles = Array.from(e.target.files || []);
    if (selectedFiles.length > 10) {
      Taro.showToast({
        title: "最多只能上传10个文件",
        icon: "error",
      });
      return;
    }


    const files = selectedFiles.map((file):TFileItem => {
      return {
        file,
        status: 0,
        fileProgress: {
          progress: 0,
          totalBytesSent: 0,
          totalBytesExpectedToSend: 0,
        },
      };
    });
    setUploadingList(files);

  };


  const handleClick = () => {
    if (process.env.TARO_ENV == "h5") {
      inputRef.current?.click();
      return;
    }
    Taro.chooseMessageFile({
      count: 10,
      type: "file",
      extension: fileTypes.map((f) => `${f}`),
      success(res) {
        const tempFilePaths = res.tempFiles;
        console.log("tempFilePaths", tempFilePaths);
        const files = tempFilePaths.map((file) => {
          return {
            file,
            status: 0,
            fileProgress: {
              progress: 0,
              totalBytesSent: 0,
              totalBytesExpectedToSend: 0,
            },
          };
        });
        setUploadingList(files);
        // setUploadList(files);
        console.log(tempFilePaths);
      },
    });
  };

  const extractType = (filename: string) => {
    return getSuffix(filename) ?? "";
  };

  const onUploadComplete = () => {
    setUploadList([]);
  };

  const handleDelete = (document: IEntityDocument) => {
    Taro.showModal({
      title: "提示",
      content: "确定删除该文件吗？",
      success(res) {
        if (res.confirm) {
          document.id && deleteDocument(document.id);
        } else if (res.cancel) {
          console.log("用户点击取消");
        }
      },
    });
  };

  useReady(() => {
    fetchDocumentList({
      page: 1,
      pageSize: 20,
      profileId: character?.profileId,
    });
  });

  const navTo = () => {
    Taro.navigateTo({
      url: "/pages/knowledge-lesson/index",
    });
  };

  const showTips = () => {
    return !documents.length && !uploadingList.length;
  };

  const renderDocList = () => {
    if (!uploadingList.length) {
      return <></>;
    }
    return (
      <UploadingDocList
        uploadList={uploadList}
        onUploadComplete={onUploadComplete}
      ></UploadingDocList>
    );
  };

  

  useDidShow(()=> {
    if(vip?.name === 'Free'){
      setVipPopupVisible(true)
    }
  })

  return (
    <PageCustom bgColor="global-light-green-bg">
      <NavBarNormal>专业知识</NavBarNormal>
      <View className="flex flex-col items-center w-full py-32 px-24">
        {process.env.TARO_ENV == "h5" && (
          <input
            type="file"
            multiple
            ref={inputRef}
            onChange={handleH5FileChange}
            accept=".ppt,.pptx,.pdf,.txt,.doc,.docx,.xls,.xlsx"
            style={{
              display: "none",
            }}
          />
        )}
        <View className={style.importCardButton} onClick={handleClick}>
          <View className={style.createButton}>
            <Image src='https://cdn.wehome.cn/cmn/png/100/META-H8UKVHWU-KIGP3BIL7M5AYC6XHNUA2-VDZCWI2M-O91.png' className={style.iconAdd}></Image>
          </View>
          <View className={style.importTips}>
            <View>导入微信文件</View>
          </View>
        </View>
      </View>
      <View className="w-full px-28">
        <View className="w-full border-t border-gray-light">
          <View className="flex flex-col items-center w-full gap-12">
            {!showTips() && (
              <View className="flex pt-32 items-center w-full px-4">
                <View className="text-black font-medium text-12 leading-24 flex-1">
                  专业知识
                </View>
                <View className="primary-color-dark text-12 " onClick={navTo}>
                  查看教程
                </View>
              </View>
            )}
            {renderDocList()}

            {documents.map((item, index) => {
              return (
                <View className={style.fileItem} key={index}>
                  <RenderIcon type={extractType(item.filename)}></RenderIcon>
                  <View className="flex flex-col flex-1 gap-2">
                    <View className={style.fileName}>{item.filename}</View>
                  </View>
                  <View
                    className={`iconfont icon-icon_24_delet icon-24 ${style.deleteButton}`}
                    onClick={() => handleDelete(item)}
                  ></View>
                </View>
              );
            })}
          </View>
        </View>
      </View>
      <View className="pb-40">{showTips() && <DocTips></DocTips>}</View>
    </PageCustom>
  );
}
