import WemetaRadio from "@/components/wemeta-radio/index";
import { getSysVoiceList } from "@/service/audio";
import { useCharacterStore } from "@/store/characterStore";
import { TServiceAudioModel } from "@/types/index";
import { Image, View } from "@tarojs/components";
import { useEffect, useState } from "react";

type ExtendedTServiceAudioModel = TServiceAudioModel & { checked: boolean };
export default function Index({ profileId,onPlay }: { profileId: string,onPlay: (voice: any) => void }) {


  const { saveCharacter } = useCharacterStore();
  const character = useCharacterStore((state) => state.character);
  const [list, setList] = useState<ExtendedTServiceAudioModel[]>([]);
  const [sysVoice, setSysVoice] = useState<ExtendedTServiceAudioModel | null>(
    null,
  );

  const initPage = async () => {
    console.log("profileId: ", profileId);
    const res = await getSysVoiceList();

    if (res.code === 0 && res.data) {
      const r = res.data.map((item) => {
        item.checked = character?.defaultSystemVoice === item.voice;
        return item;
      }) as ExtendedTServiceAudioModel[];
      const checkedVoice = r.find((item) => !!item.checked);
      if (checkedVoice) {
        setSysVoice(checkedVoice);
      }
      setList(r);
    }
  };

  const handleSelect = async (voiceItem: ExtendedTServiceAudioModel) => {
    console.log("system voice select");

    const _list = list.map((item) => {
      return { ...item, checked: item.voice === voiceItem.voice };
    });

    setList(_list);

    setSysVoice(voiceItem);
    if (profileId) {
      saveCharacter({
        defaultSystemVoice: voiceItem.voice,
        voice: voiceItem.voice,
        profileId: profileId,
      });
    }
    // playerRef.current && playerRef.current.play(voiceItem.voice);
    onPlay && onPlay(voiceItem)
  };

  useEffect(() => {
    console.log("系统声音页面显示");
    initPage();
  },[profileId]);

  return (
    <View className='w-full'>
      {/* <View className='sticky  left-0 right-0 ' style={{
        top:'50px',
        backgroundColor:'#F5F5F2'
      }}>
        <VoicePlayerBar ref={playerRef} voiceItem={sysVoice} />
      </View> */}
      <View className='px-16 bg-white rounded-20'>
        <View className='flex flex-col w-full gap-28 px-16 py-24 rounded-20 '>
          {list.map((item: ExtendedTServiceAudioModel) => {
            // 与克隆语音是否相同
            const isEqualToClonedVoice = (item.voice === character?.voice)
            return (
              <View
                className='flex gap-16 w-full'
                key={item.id}
                onClick={() => {
                  handleSelect(item);
                }}
              >
                <Image
                  src={item.avatar}
                  mode='widthFix'
                  className='w-56 h-56 rounded-12 shrink-0'
                ></Image>
                <View className='flex flex-1 flex-col gap-4 overflow-hidden'>
                  <View className='text-14 leading-22 font-medium text-black'>
                    {item.name}
                  </View>
                  <View className='flex-1 text-12 leading-20 font-medium text-gray-45 truncate'>
                    {item.gender === 1 ? "男" : "女"} {item.style}
                  </View>
                </View>
                <View className='flex items-center'>
                  <WemetaRadio checked={item.checked && isEqualToClonedVoice}></WemetaRadio>
                </View>
              </View>
            );
          })}
        </View>
      </View>
    </View>
  );
}
