import { View, ScrollView, Text } from "@tarojs/components";
import Taro, { useReady } from "@tarojs/taro";
import NavBarNormal from "@/components/nav-bar-normal/index";
import { useAppStore } from "@/store/appStore";
import { useUserStore } from "@/store/userStore";
import style from "./index.module.less";
import { useState } from "react";
import PriceCards from "./components/price-cards/index";
import VipRights from "./components/vip-rights/index";
import PopupPaySuccess from "@/components/popup/popup-pay-success/index";
import { payVip } from "@/service/pay";
import { TPaySign } from "@/types/index";
import PopupMp from "@/components/popup/popup-mp";
import {  navToWebView } from '@/utils/index'
import { APP_AGREEMENT_URL } from '@/config'
import {reportPageVisit} from '@/utils/report'
export default () => {
  const headerHeight = useAppStore((state) => state.headerHeight);
  const appConfig = useAppStore((state) => state.appConfig);
  const isIos = useAppStore((state) => state.isIos);
  const [visible, setVisible] = useState(false)
  let paying = false;
  const [showSuccess, setShowSuccess] = useState(false);
  const { fetchUser } = useUserStore();
  const prices = appConfig?.vips?.find(
    (item) => item.id === "vip_plus"
  )?.prices;
  // const [tabIndex, setTabIndex] = useState(0);
  let priceId: number | undefined = prices?.[0].id;
  const { fetchAppConfig } = useAppStore();
  const handleSelected = (_priceId: number) => {
    console.log(_priceId);
    priceId = _priceId;
  };
  const goPay = async () => {
    if(isIos){
      Taro.showModal({
        content: '根据微信规定，iOS平台暂不提供支付功能。',
        showCancel: false,
      });
      // setVisible(true)
      return
    }
    if (paying) {
      return;
    }
    if (!priceId) {
      return;
    }
    paying = true;
    const res = await payVip(priceId);
    if (!res?.data?.sign) {
      paying = false;
      return;
    }
    const sign = JSON.parse(res.data.sign) as TPaySign;
    console.log(res);
    //@ts-ignore
    Taro.requestPayment({
      ...sign,
      success(res) {
        console.log(res);
        fetchUser();
        setShowSuccess(true);
        paying = false
        // Taro.showToast({ title: '支付成功', icon: 'success'});
      },
      fail(res) {
        Taro.showToast({ title: "支付失败", icon: "error" });
        paying = false
        console.log(res);
      },
    });
  };
  useReady(() => {
    fetchAppConfig();
  });

  reportPageVisit()
  
  
  return (
    // 有横向滚动，页面需要特殊处理
    <View className="relative">
      <View
        className={`global-color flex flex-col index`}
        style={{ paddingTop: headerHeight }}
      >
        <NavBarNormal>升级会员</NavBarNormal>
        <PopupMp show={visible} onClose={()=> setVisible(false)}></PopupMp>
        <PopupPaySuccess
          show={showSuccess}
          onClose={() => setShowSuccess(false)}
        ></PopupPaySuccess>
        
        {appConfig && (
          <View className={style.tab}>
            {/* <View className={style.tabBarContainer}>
              <View
                className={`${
                  tabIndex === 0 ? style.tabBarActived : style.tabBar
                }`}
              >
                <View>高级会员</View>
              </View>
              <View className={`${style.tabBar}`}>
                <View>超级会员</View>
              </View>
            </View> */}
            <View className={`${style.tabContent}`}>
              <View className={style.priceScrollView}>
                <ScrollView
                  scroll-x="true"
                  enable-flex
                  className="whitespace-nowrap w-full mb-26"
                >
                  {(!isIos && prices) && <PriceCards
                    onSelected={handleSelected}
                    prices={prices}
                  ></PriceCards>}
                </ScrollView>
              </View>
              <View className="px-28">
                <View
                  className="full-rounded-button"
                  onClick={() => {
                    goPay();
                  }}
                >
                  申请开通会员
                </View>
                <View className="text-center pt-16 pb-36 text-12 leading-20" onClick={()=> navToWebView(APP_AGREEMENT_URL)}>
                  <Text className="text-6">开通前阅读并同意</Text>
                  <Text className="primary-color-dark">《会员服务协议》</Text>
                </View>
                <VipRights appConfig={appConfig}></VipRights>
              </View>
            </View>
          </View>
        )}
      </View>
    </View>
  );
};
